@@ -10,9 +10,11 @@ def _apply_highlight(text:str, highlight:str, color:str, hl_color:str=Fore.YELLO
     highlighted_text = text
 
     if isinstance(highlight, str):
+        highlight = str(highlight)
         highlighted_text = highlighted_text.replace(highlight, hl_color + highlight + color)
     elif isinstance(highlight, list):
         for hl in highlight:
+            hl = str(hl)
             highlighted_text = highlighted_text.replace(hl, hl_color + hl + color)
 
     return highlighted_text
@@ -52,7 +54,7 @@ class Log:
             raw_text = ' '.join([str(c) for c in content])
 
             # Highlight text
-            highlighted_text = _apply_highlight(raw_text, str(highlight), Fore.GREEN)
+            highlighted_text = _apply_highlight(raw_text, highlight, Fore.GREEN)
 
             finished_text = f'{Timestamp.get(internal_call=True)}{Fore.GREEN}[i] {highlighted_text}{Fore.RESET}'
             print(finished_text)
@@ -80,7 +82,7 @@ class Log:
             raw_text = ' '.join([str(c) for c in content])
 
             # Highlight text
-            highlighted_text = _apply_highlight(raw_text, str(highlight), Fore.YELLOW, Fore.WHITE)
+            highlighted_text = _apply_highlight(raw_text, highlight, Fore.YELLOW, Fore.WHITE)
 
             finished_text = f'{Timestamp.get(internal_call=True)}{Fore.YELLOW}[w] {highlighted_text}{Fore.RESET}'
             print(finished_text)
@@ -109,7 +111,7 @@ class Log:
             raw_text = ' '.join([str(c) for c in content])
 
             # Highlight text
-            highlighted_text = _apply_highlight(raw_text, str(highlight), Fore.RED)
+            highlighted_text = _apply_highlight(raw_text, highlight, Fore.RED)
 
             finished_text = f'{Timestamp.get(internal_call=True)}{Fore.RED}[!] {highlighted_text}{Fore.RESET}'
             print(finished_text)
@@ -139,7 +141,7 @@ class Log:
             raw_text = ' '.join([str(c) for c in content])
 
             # Highlight text
-            highlighted_text = _apply_highlight(raw_text, str(highlight), Fore.LIGHTBLACK_EX)
+            highlighted_text = _apply_highlight(raw_text, highlight, Fore.LIGHTBLACK_EX)
 
             finished_text = f'{Timestamp.get(internal_call=True)}{Fore.LIGHTBLACK_EX}[?] {highlighted_text}{Fore.RESET}'
             print(finished_text)
